@@ -13,7 +13,7 @@ use English '-no_match_vars';
 use 5.006;
 
 # Declare package version
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # Patterns to match elements of the LRC file; these are somewhat tolerant
 our %RE = (
@@ -211,7 +211,7 @@ sub save {
         my %ts   = %{ $self->msec_to_ts($msec) };
 
         # Write the line to the file, counting the lines
-        $lines += printf {$fh} "[%02u:%02u:%02u]%s\n",
+        $lines += printf {$fh} "[%02u:%02u.%02u]%s\n",
           @ts{qw(min sec csec)}, $lyric->{text}
           or die "Failed lyric write: $ERRNO\n";
     }
@@ -264,7 +264,7 @@ Music::Lyrics::LRC - Manipulate LRC karaoke timed lyrics files
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =head1 DESCRIPTION
 
